/* $Id: sinfo_rec_mdark_detmon.c,v 1.3 2008/02/28 10:36:41 amodigli Exp $
 *
 * This file is part of the DETMON Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: amodigli $
 * $Date: 2008/02/28 10:36:41 $
 * $Revision: 1.3 $
 * $Name: sinfo-2_2_5 $
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

/*----------------------------------------------------------------------------
                             Includes
 ----------------------------------------------------------------------------*/

#include <cpl.h>

#include "irplib_detmon.h"
#include "irplib_plugin.h"

/* Define here the DO.CATG keywords */
#define SINFONI_DARK_RAW                    "DARK"

#define RECIPE_NAME "sinfo_rec_mdark_detmon"

/*----------------------------------------------------------------------------
				Functions prototypes
 ----------------------------------------------------------------------------*/

IRPLIB_RECIPE_DEFINE(sinfo_rec_mdark_detmon, SINFONI_BINARY_VERSION,
                     irplib_detmon_fill_dark_params_default(recipe->parameters,
                                                       "sinfo_rec_mdark_detmon",
                                                       "sinfo"),
                     "Lander de Bilbao", "lbilbao@eso.org", "2008", 
                     "Master dark and detector signal non uniformity map",
                     irplib_detmon_dark_get_description(RECIPE_NAME,
                                                           "SINFONI",
                                                           SINFONI_DARK_RAW));

/*---------------------------------------------------------------------------*/
/*
  @brief    Interpret the command line options and execute the data processing
  @param    frameset    the frames list
  @param    parlist     the parameters list
  @return   0 if everything is ok
 */
/*---------------------------------------------------------------------------*/

static int sinfo_rec_mdark_detmon(cpl_frameset            * frameset,
		       const cpl_parameterlist * parlist)
{
    const cpl_error_code error = irplib_detmon_dark(frameset,
						    parlist,
						    SINFONI_DARK_RAW,
						    RECIPE_NAME,
						    PACKAGE_TARNAME,
						    "MASTER_DARK",
						    "DSNU_MAP",
						    "DSNU_TABLE",
                                                       PACKAGE "/" PACKAGE_VERSION,
                                                       NULL);


    /* Propagate the error, if any */
    cpl_ensure_code(!error, error);

    return CPL_ERROR_NONE;
}
